MethodChannelPacketIosSdk class

An implementation of PacketIosSdkPlatform that uses method channels.

Inheritance

Constructors

MethodChannelPacketIosSdk()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isOptIn() Future<bool?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optIn() Future<String?>
override
optOut() Future<String?>
override
requestConsent() Future<String?>
override
SetAppKey(String appKey) Future<String?>
override
Start() Future<String?>
override
Stop() Future<String?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited